/**
 * $Id: FileHelper.java,v 1.1 2009/03/23 15:27:01 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 11.09.2008 by oliver (ob@oasd.de)
 */
package patterntesting.exception.io;

import java.io.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.LogFactoryImpl;

/**
 * This class is a collection of some helpful methods for the File class.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 11.09.2008
 * @version $Revision: 1.1 $
 */
public class FileHelper {
	
	private static final Log log = LogFactoryImpl.getLog(FileHelper.class);
	
	/**
	 * @return the tmp dir (e.g. "/tmp" under Linux/Unix)
	 */
	public static File getTmpdir() {
		return new File(System.getProperty("java.io.tmpdir"));
	}
	
	/**
	 * @param file e.g. "hugo"
	 * @return the given file in the tmp dir (e.g. "/tmp/hugo")
	 */
	public static File getTmpdir(File file) {
		return getTmpdir(file.toString());
	}
	
	/**
	 * 
	 * @param filename e.g. "hugo"
	 * @return the given file in the tmp dir (e.g. "/tmp/hugo")
	 */
	public static File getTmpdir(String filename) {
		return new File(getTmpdir(), filename);
	}
	
	/**
	 * Wraps the given IOException and file into a better IOException
	 * (with the absolute path in the error message)
	 * 
	 * @param ioe the original IOException
	 * @param file the file which causes the IOException
	 * @return a better IOException
	 */
	public static IOException betterIOException(IOException ioe, File file) {
		return betterIOException(ioe, file.getAbsolutePath());
	}
	
	/**
	 * The cause of the given IOException is ignored for the moment bcause
	 * the constructor IOException(String s, Throwable t) is not available
	 * in Java 5.
	 * 
	 * @param ioe the original IOException
	 * @param filename which caused the IOExeption
	 * @return
	 */
	public static IOException betterIOException(IOException ioe,
			String filename) {
		String msg = ioe.getMessage() + ": " + filename;
		Throwable cause = ioe.getCause();
		if (cause == null) {
			return new IOException(msg);
		} else {
			log.warn("cause: " + cause);
			return new IOException(msg);
		}
	}

}

/**
 * $Log: FileHelper.java,v $
 * Revision 1.1  2009/03/23 15:27:01  oboehm
 * IOExceptionAspect moved from patterntesting-rt to here
 *
 * Revision 1.2  2009/02/14 22:19:51  oboehm
 * javadoc comments added and updated
 *
 * Revision 1.1  2008/12/07 13:53:38  oboehm
 * refactorings and minor reorganisations
 *
 * Revision 1.1  2008/11/06 22:12:43  oboehm
 * begin of split in runtime components and others
 *
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-exception/src/main/java/patterntesting/exception/io/FileHelper.java,v $
 */
